@@ -24,7 +24,7 @@
 *
 *****************************************************************************/
 
-/* $Id: qmc.h 5087 2010-11-10 21:11:46Z troyer $ */
+/* $Id: qmc.h 7707 2016-05-24 07:57:52Z hehn $ */
 
 #ifndef ALPS_APPLICATIONS_QMC_H
 #define ALPS_APPLICATIONS_QMC_H
@@ -71,6 +71,7 @@ protected:
   unsigned maximum_sitetype;
   state_type maximum_number_of_states;
   std::map<int,int> number_states_for_site_type_;
+  std::vector<int>        site_site_type;
   std::vector<state_type> site_number_of_states; 
 
   std::map<std::string,std::vector<std::vector<double> > > diagonal_matrix_element;
@@ -171,6 +172,7 @@ void QMCRun<G,StateType>::initialize_site_states()
     unsigned int sitetype=alps::scheduler::LatticeModelMCRun<G>::site_type(*it);
     if (sitetype > maximum_sitetype)
       maximum_sitetype = sitetype;
+    site_site_type.push_back(sitetype);
     std::map<int,int>::const_iterator found = number_states_for_site_type_.find(sitetype);
     if (found != number_states_for_site_type_.end())
       site_number_of_states.push_back(found->second);
@@ -611,8 +613,10 @@ bool QMCRun<G,StateType>::do_common_measurements(double sign, const std::vector<
     for (typename super_type:: momentum_iterator mit=this->momenta().first; mit != this->momenta().second; ++mit) {
       std::complex<double> vala, valb;
       for (typename super_type::site_iterator sit=this->sites().first; sit!=this->sites().second;++sit) {
-        vala += local_a[*sit]*mit.phase(alps::scheduler::LatticeModelMCRun<G>::coordinate(*sit));
-        valb += local_b[*sit]*mit.phase(alps::scheduler::LatticeModelMCRun<G>::coordinate(*sit));
+        double phase = alps::numeric::scalar_product(this->momentum(*mit), alps::scheduler::LatticeModelMCRun<G>::coordinate(*sit));
+        std::complex<double> cphase(std::cos(phase), std::sin(phase));
+        vala += local_a[*sit] * cphase;
+        valb += local_b[*sit] * cphase;
       }
       str.push_back(std::real(std::conj(vala)*valb));
     }
@@ -626,9 +630,11 @@ bool QMCRun<G,StateType>::do_common_measurements(double sign, const std::vector<
     std::vector<double> str;
     for (typename super_type:: momentum_iterator mit=this->momenta().first; mit != this->momenta().second; ++mit) {
       std::complex<double> val;
-      for (typename super_type::site_iterator sit=this->sites().first; sit!=this->sites().second;++sit)
-        val += local[*sit]*mit.phase(alps::scheduler::LatticeModelMCRun<G>::coordinate(*sit));
-      str.push_back(std::abs(val)*std::abs(val));
+      for (typename super_type::site_iterator sit=this->sites().first; sit!=this->sites().second;++sit) {
+        double phase = alps::numeric::scalar_product(this->momentum(*mit), alps::scheduler::LatticeModelMCRun<G>::coordinate(*sit));
+        val += local[*sit] * std::complex<double>(std::cos(phase), std::sin(phase));
+      }
+      str.push_back(std::norm(val));
     }
     std::valarray<double> strv(str.size());
     for (int i=0;i<str.size();++i)
