@@ -1,3 +1,5 @@
+from __future__ import print_function
+from __future__ import absolute_import
 # ****************************************************************************
 # 
 # ALPS Project: Algorithms and Libraries for Physics Simulations
@@ -32,8 +34,8 @@ import numpy as np
 import pyalps.hdf5 as h5
 import pyalps.alea as pa
 
-from dataset import ResultFile
-from dataset import DataSet
+from .dataset import ResultFile
+from .dataset import DataSet
 #from floatwitherror import FloatWithError as fwe
 
 import pyalps.pytools as pt # the C++ conversion functions
@@ -44,7 +46,7 @@ from pyalps.alea import MCVectorData as vwe
 
 in_vistrails=True
 try:
-  import core.modules.basic_modules
+  import vistrails.core.modules.basic_modules
   from core import debug
 except:
   in_vistrails=False
@@ -54,7 +56,7 @@ def log(m):
     if in_vistrails:
       debug.log(str(m))
     else:
-      print m
+      print(m)
     
 def parse_label(label):
     if '--' in label:
@@ -80,7 +82,7 @@ def parse_labels(labels):
         if first==None:
           first = v[0]
         else:
-          if first != v[0]:
+          if first != v[0] or len(v) != 2:
             allsame = False
       else:
         allsame = False
@@ -116,11 +118,11 @@ class Hdf5Loader:
         LOP=self.h5f.list_children(proppath)
         for m in LOP:
                 try:
-                    dict[m] = self.h5f.read(proppath+'/'+m)
+                    dict[m] = self.h5f[proppath+'/'+m]
                     try:
                         dict[m] = float(dict[m])
                     except:
-                        dict[m] = map(float,dict[m])
+                        dict[m] = list(map(float,dict[m]))
                 except ValueError:
                     pass
         return dict 
@@ -130,7 +132,7 @@ class Hdf5Loader:
         resultfiles = []
         for f in fs:
             try:
-                self.h5f = h5.iArchive(f)
+                self.h5f = h5.archive(f, 'r')
                 self.h5fname = f
                 if verbose: log( "Loading from file" + f)
                 rfile = ResultFile(f)
@@ -140,7 +142,7 @@ class Hdf5Loader:
                     rfile.props["ObservableList"] = [pt.hdf5_name_decode(x) for x in obs]
                 except: pass
                 resultfiles.append(rfile)
-            except Exception, e:
+            except Exception as e:
                 log(e)
                 log(traceback.format_exc())
         return resultfiles
@@ -164,7 +166,7 @@ class Hdf5Loader:
         for f in fs:
             try:
                 fileset=[]
-                self.h5f = h5.iArchive(f)
+                self.h5f = h5.archive(f, 'r')
                 self.h5fname = f
                 if verbose: log("Loading from file " + f)
                 params = self.ReadParameters(proppath)
@@ -173,7 +175,7 @@ class Hdf5Loader:
                             d = DataSet()
                             d.props['hdf5_path'] = respath 
                             d.props['observable'] = 'spectrum'
-                            d.y = self.h5f.read(respath+'/energies')
+                            d.y = self.h5f[respath+'/energies']
                             d.x = range(len(d.y))
                             d.props.update(params)
                             try:
@@ -191,7 +193,7 @@ class Hdf5Loader:
                             secpath = respath+'/sectors/'+secnum
                             d.props['hdf5_path'] = secpath 
                             d.props['observable'] = 'spectrum'
-                            d.y = self.h5f.read(secpath+'/energies')
+                            d.y = self.h5f[secpath+'/energies']
                             d.x = range(len(d.y))
                             d.props.update(params)
                             try:
@@ -204,18 +206,65 @@ class Hdf5Loader:
                             log( "Could not create DataSet")
                             pass
                 sets.append(fileset)
-            except Exception, e:
+            except Exception as e:
                 log(e)
                 log(traceback.format_exc())
         return sets
-
+        
+    def GetIterations(self, current_path, params={}, measurements=None, index=None, verbose=False):
+        iterationset=[]
+        #iteration_grp = self.h5f.require_group(respath+'/iteration')
+        for it in self.h5f.list_children(current_path+'/iteration'):
+            obsset=[]
+            iteration_props = {}
+            if 'parameters' in self.h5f.list_children(current_path+'/iteration/'+it):
+                iteration_props = self.ReadParameters(current_path+'/iteration/'+it+'/parameters')
+            iteration_props['iteration'] = it
+            
+            respath = current_path+'/iteration/'+it+'/results'
+            list_ = self.GetObservableList(respath)
+            if measurements == None:
+                obslist = list_
+            else:
+                obslist = [pt.hdf5_name_encode(obs) for obs in measurements if pt.hdf5_name_encode(obs) in list_]
+            for m in obslist:
+                if m in self.h5f.list_children(respath):
+                    if "mean" in self.h5f.list_children(respath+'/'+m):
+                        try:
+                            d = DataSet()
+                            itresultspath = respath+'/'+m
+                            if verbose: log("Loading "+ m)
+                            measurements_props = {}
+                            measurements_props['hdf5_path'] = itresultspath 
+                            measurements_props['observable'] = pt.hdf5_name_decode(m)
+                            if index == None:
+                                d.y = self.h5f[itresultspath+'/mean/value']
+                                d.x = np.arange(0,len(d.y))
+                            else:
+                                try:
+                                    d.y = self.h5f[itresultspath+'/mean/value'][index]
+                                except:
+                                    pass
+                            if "labels" in self.h5f.list_children(itresultspath):
+                                d.x = parse_labels(self.h5f[itresultspath+'/labels'])
+                            else:
+                                d.x = np.arange(0,len(d.y))
+                            d.props.update(params)
+                            d.props.update(iteration_props)
+                            d.props.update(measurements_props)
+                        except AttributeError:
+                            log( "Could not create DataSet")
+                    obsset.append(d)
+            iterationset.append(obsset)
+        return iterationset
+        
     def ReadDiagDataFromFile(self,flist,proppath='/parameters',respath='/spectrum', measurements=None, index=None, loadIterations=False,verbose=False):
         fs = self.GetFileNames(flist)
         sets = []
         for f in fs:
             try:
                 fileset=[]
-                self.h5f = h5.iArchive(f)
+                self.h5f = h5.archive(f, 'r')
                 self.h5fname = f
                 if verbose: log("Loading from file"+ f)
                 params = self.ReadParameters(proppath)
@@ -226,39 +275,8 @@ class Hdf5Loader:
                     else:
                         obslist = [pt.hdf5_name_encode(obs) for obs in measurements if pt.hdf5_name_encode(obs) in list_]
                     if loadIterations==True:
-                        if "iteration" in self.h5f.list_children(respath):
-                            iterationset=[]
-                            #iteration_grp = self.h5f.require_group(respath+'/iteration')
-                            for it in self.h5f.list_children(respath+'/iteration'):
-                                obsset=[]
-                                for m in obslist:
-                                    if m in self.h5f.list_children(respath+'/iteration/'+it+'/results'):
-                                        if "mean" in self.h5f.list_children(respath+'/iteration/'+it+'/results/'+m):
-                                            try:
-                                                d = DataSet()
-                                                itresultspath = respath+'/iteration/'+it+'/results/'+m
-                                                if verbose: log("Loading "+ m)
-                                                d.props['hdf5_path'] = itresultspath 
-                                                d.props['observable'] = pt.hdf5_name_decode(m)
-                                                d.props['iteration'] = it
-                                                if index == None:
-                                                    d.y = self.h5f.read(itresultspath+'/mean/value')
-                                                    d.x = np.arange(0,len(d.y))
-                                                else:
-                                                    try:
-                                                        d.y = self.h5f.read(itresultspath+'/mean/value')[index]
-                                                    except:
-                                                        pass
-                                                if "labels" in self.h5f.list_children(itresultspath):
-                                                    d.x = self.h5f.read(itresultspath+'/labels') 
-                                                else:
-                                                    d.x = np.arange(0,len(d.y))
-                                                d.props.update(params)
-                                            except AttributeError:
-                                                log( "Could not create DataSet")
-                                        obsset.append(d)
-                                iterationset.append(obsset)
-                            fileset.append(iterationset)
+                        if "iteration" in self.h5f.list_children(respath+'/results'):
+                            fileset.append(self.GetIterations(respath+'/results', params, measurements, index, verbose))
                     else:        
                         for m in obslist:
                             if "mean" in self.h5f.list_children(respath+'/results/'+m):
@@ -269,22 +287,25 @@ class Hdf5Loader:
                                     d.props['hdf5_path'] = secresultspath 
                                     d.props['observable'] = pt.hdf5_name_decode(m)
                                     if index == None:
-                                        d.y = self.h5f.read(secresultspath+'/mean/value') 
+                                        d.y = self.h5f[secresultspath+'/mean/value']
                                         d.x = np.arange(0,len(d.y))
                                     else:
                                         try:
-                                            d.y = self.h5f.read(secresultspath+'/mean/value')[index]
+                                            d.y = self.h5f[secresultspath+'/mean/value'][index]
                                         except:
                                             pass
                                     if "labels" in self.h5f.list_children(secresultspath):
-                                        d.x = parse_labels(self.h5f.read(secresultspath+'/labels'))
+                                        d.x = parse_labels(self.h5f[secresultspath+'/labels'])
                                     else:
                                         d.x = np.arange(0,len(d.y))
                                     d.props.update(params)
-
+                                    
+                                    fileset.append(d)
                                 except AttributeError:
                                     log("Could not create DataSet")
-                            fileset.append(d)
+                if loadIterations==True:
+                    if "iteration" in self.h5f.list_children(respath):
+                        fileset.append(self.GetIterations(respath, params, measurements, index, verbose))
                 if 'sectors' in self.h5f.list_children(respath):
                     list_ = self.GetObservableList(respath+'/sectors/0/results')
                     if measurements == None:
@@ -303,15 +324,15 @@ class Hdf5Loader:
                                     d.props['hdf5_path'] = secresultspath 
                                     d.props['observable'] = pt.hdf5_name_decode(m)
                                     if index == None:
-                                        d.y = self.h5f.read(secresultspath+'/mean/value') 
+                                        d.y = self.h5f[secresultspath+'/mean/value']
                                         d.x = np.arange(0,len(d.y))
                                     else:
                                         try:
-                                            d.y = self.h5f.read(secresultspath+'/mean/value')[index]
+                                            d.y = self.h5f[secresultspath+'/mean/value'][index]
                                         except:
                                             pass
                                     if "labels" in self.h5f.list_children(secresultspath):
-                                        d.x = parse_labels(self.h5f.read(secresultspath+'/labels')) 
+                                        d.x = parse_labels(self.h5f[secresultspath+'/labels'])
                                     else:
                                         d.x = np.arange(0,len(d.y))
                                     d.props.update(params)
@@ -329,7 +350,7 @@ class Hdf5Loader:
                 sets.append(fileset)
             except RuntimeError:
                 raise
-            except Exception, e:
+            except Exception as e:
                 log(e)
                 log(traceback.format_exc())
         return sets
@@ -343,7 +364,7 @@ class Hdf5Loader:
             try:
                 fileset = []
                 if verbose: log( 'loading from file ' +f)
-                self.h5f = h5.iArchive(f)
+                self.h5f = h5.archive(f, 'r')
                 self.h5fname = f
                 if respath == None:
                   respath="/simulation/results"
@@ -363,9 +384,9 @@ class Hdf5Loader:
                             k = self.h5f.list_children(respath+'/'+m+'/timeseries')
                             if "logbinning" in k and "logbinning2" in k and "logbinning_counts" in k:
                                 if verbose: log("Loading"+ m)
-                                bins = self.h5f.read(respath+'/'+m+'/timeseries/logbinning')[0:-4] 
-                                bins2 = self.h5f.read(respath+'/'+m+'/timeseries/logbinning2')[0:-4] 
-                                counts = self.h5f.read(respath+'/'+m+'/timeseries/logbinning_counts')[0:-4] 
+                                bins = self.h5f[respath+'/'+m+'/timeseries/logbinning'][0:-7]
+                                bins2 = self.h5f[respath+'/'+m+'/timeseries/logbinning2'][0:-7]
+                                counts = self.h5f[respath+'/'+m+'/timeseries/logbinning_counts'][0:-7]
                                 scale = 1
                                 for i in range(len(counts)):
                                     mean = bins[i]/(counts[i]*scale)
@@ -382,7 +403,7 @@ class Hdf5Loader:
                     except AttributeError:
                         log( "Could not create DataSet")
                 sets.append(fileset)
-            except Exception, e:
+            except Exception as e:
                 log( e)
                 log( traceback.format_exc())
         return sets
@@ -395,9 +416,9 @@ class Hdf5Loader:
         for f in fs:
             try:
                 fileset = []
-                self.h5f = h5.iArchive(f)
+                self.h5f = h5.archive(f, 'r')
                 self.h5fname = f
-                if verbose: log("Loading from file" + f)
+                if verbose: log("Loading from file " + f)
                 list_ = self.GetObservableList(respath)
                 params = self.ReadParameters(proppath)
                 obslist = []
@@ -410,33 +431,59 @@ class Hdf5Loader:
                     size=0
                     xmin=0
                     xstep=1
+                    x=None
                     if "histogram" in self.h5f.list_children(respath+'/'+m):
-                        obs = self.h5f.read(respath+'/'+m+'/histogram')
-                        xmin = self.h5f.read(respath+'/'+m+'/@min')
-                        xstep = self.h5f.read(respath+'/'+m+'/@stepsize')
+                        obs = self.h5f[respath+'/'+m+'/histogram']
+                        xmin = self.h5f[respath+'/'+m+'/@min']
+                        xstep = self.h5f[respath+'/'+m+'/@stepsize']
                         size = len(obs)
+                        x = np.arange(xmin,xmin+xstep*size,xstep)
                     elif "error" in self.h5f.list_children(respath+'/'+m+'/mean'): 
                         if self.h5f.is_scalar(respath+'/'+m+'/mean/value'):
                             obs = pa.MCScalarData()
                             obs.load(self.h5fname, respath+'/'+m)
                             obs=np.array([obs])
                             size=1
+                            if obs[0].count==0:
+                              obs=None
                         else:
-                            obs = pa.MCVectorData()
-                            obs.load(self.h5fname, respath+'/'+m)
-                            size=len(obs.mean)
+                            obs=None
+                            if not self.h5f.is_group(respath+'/'+m+'/timeseries'): # check for simple binning
+                                obs = np.array(self.h5f[respath+'/'+m+'/mean/value']);
+                                if 'L' in params: # ugly fix... really ugly
+                                  L = int(params['L'])
+                                  if L == obs.size:
+                                    params['origin'] = [(L-1.)/2.];
+                                  if L**2 == obs.size: # dimension 2
+                                    obs = obs.reshape([L,L]);
+                                    params['origin'] = [(L-1.)/2., (L-1.)/2.];
+                                  elif L**3 == obs.size: # dimension 3
+                                    obs = obs.reshape([L,L,L]);
+                                    params['origin'] = [(L-1.)/2., (L-1.)/2., (L-1.)/2.];
+                                size = obs.size
+                            else:
+                                obs = pa.MCVectorData()
+                                obs.load(self.h5fname, respath+'/'+m)
+                                size=len(obs.mean)
+                                if obs.count==0:
+                                    obs=None
                     else:
                         if self.h5f.is_scalar(respath+'/'+m+'/mean/value'):
-                            obs = self.h5f.read(respath+'/'+m+'/mean/value')
+                            obs = self.h5f[respath+'/'+m+'/mean/value']
                             obs=np.array([obs])
                             size=1
                         else:
-                            obs = self.h5f.read(respath+'/'+m+'/mean/value')
+                            obs = self.h5f[respath+'/'+m+'/mean/value']
                             size=len(obs)
+                    if "labels" in self.h5f.list_children(respath+'/'+m) and x is None:
+                        x = parse_labels(self.h5f[respath+'/'+m+'/labels'])
+                    elif x is None:
+                        x = np.arange(xmin,xmin+xstep*size,xstep)
                     try:
+                      if obs is not None:
                         d = DataSet()
                         d.y = obs
-                        d.x = np.arange(xmin,xmin+xstep*size,xstep)
+                        d.x = x
                         d.props['hdf5_path'] = respath +"/"+ m
                         d.props['observable'] = pt.hdf5_name_decode(m)
                         d.props.update(params)
@@ -444,29 +491,25 @@ class Hdf5Loader:
                     except AttributeError:
                         log( "Could not create DataSet")
                 sets.append(fileset)
-            except Exception, e:
+            except Exception as e:
                 log(e)
                 log(traceback.format_exc())
         return sets
 
     # Pre: file is a hdf5 file descriptor
     # Post: returns DataSet with all parameters set
-    def ReadDMFTIterations(self,flist,measurements=None,proppath='/parameters',respath='/simulation/iteration',verbose=False):
+    def ReadDMFTIterations(self,flist,observable='G_tau',measurements='0',proppath='/parameters',respath='/simulation/iteration',verbose=False):
         fs = self.GetFileNames(flist)
         fileset = []
         for f in fs:
             try:
-                self.h5f = h5.iArchive(f)
+                self.h5f = h5.archive(f, 'r')
                 self.h5fname = f
                 if verbose: log("Loading from file "+ f)
-                list_ = self.GetObservableList(respath+'/1/results/G_tau/')
+                list_ = self.GetObservableList(respath+'/1/results/'+observable+'/')
                 #grp = self.h5f.require_group(respath)
                 params = self.ReadParameters(proppath)
-                obslist = []
-                if measurements == None:
-                    obslist = ['Green_0']
-                else:
-                    obslist = [pt.hdf5_name_encode(obs) for obs in measurements if pt.hdf5_name_encode(obs) in list_]
+                obslist = [pt.hdf5_name_encode(obs) for obs in measurements if pt.hdf5_name_encode(obs) in list_]
                 iterationset=[]
                 for it in  self.h5f.list_children(respath):
                     obsset=[]
@@ -475,14 +518,14 @@ class Hdf5Loader:
                             if verbose: log( "Loading "+ m)
                             d = DataSet()
                             size=0
-                            path=it+"/results/G_tau/"+m
+                            path=it+'/results/'+observable+'/'+m
                             if "mean" in self.h5f.list_children(respath+'/'+path):
                                 if self.h5f.is_scalar(respath+'/'+path+'/mean/value'):
                                     size=1
-                                    obs=self.h5f.read(respath+'/'+path+'/mean/value')
+                                    obs=self.h5f[respath+'/'+path+'/mean/value']
                                     d.y = np.array([obs]) 
                                 else:
-                                    obs=self.h5f.read(respath+'/'+path+'/mean/value')
+                                    obs=self.h5f[respath+'/'+path+'/mean/value']
                                     size=len(obs)
                                     d.y = obs
                                 d.x = np.arange(0,size)
@@ -496,52 +539,52 @@ class Hdf5Loader:
                         obsset.append(d)
                     iterationset.append(obsset)
                 fileset.append(iterationset)
-            except Exception, e:
+            except Exception as e:
                 log( e)
                 log( traceback.format_exc())
         return fileset
         
-def loadBinningAnalysis(files,what=None,verbose=False):
+def loadBinningAnalysis(files,what=None,verbose=False,respath='/simulation/results'):
     """ loads MC binning analysis from ALPS HDF5 result files
     
         this function loads results of a MC binning analysis from ALPS HDF5 result files
         
-        The parameters are:
+        Parameters:
+            files (list): ALPS result files which can be either XML or HDF5 files. XML file names will be changed to the corresponding HDF5 names.
+            what (list): optional argument that is either a string or list of strings, specifying the names of the observables for which the binning analysis should be loaded
+            verbose (bool): optional argument that if set to True causes more output to be printed as the data is loaded
         
-        files: a list of ALPS result files which can be either XML or HDF5 files. XML file names will be changed to the corresponding HDF5 names.
-        what: an optional argument that is either a string or list of strings, specifying the names of the observables for which the binning analysis should be loaded
-        verbose: an optional boolean argument that if set to True causes more output to be printed as the data is loaded
-        
-        The function returns a list of list of DataSet objects. 
-        The elements of the outer list each correspond to the file names specified as input.
-        The elements of the inner list are each for a different observable.
-        The x-values of the DataSet objects are the logarithmic binning level and the y-values the error estimates at that binning level.
+        Returns:
+            a list of list of DataSet objects: loaded binning analysis.
+            The elements of the outer list each correspond to the file names specified as input.
+            The elements of the inner list are each for a different observable.
+            The x-values of the DataSet objects are the logarithmic binning level and the y-values the error estimates at that binning level.
     """
     ll = Hdf5Loader()
     if isinstance(what,str):
       what = [what]
     return ll.ReadBinningAnalysis(files,measurements=what,verbose=verbose)
 
-def loadMeasurements(files,what=None,verbose=False):
+def loadMeasurements(files,what=None,verbose=False,respath='/simulation/results'):
     """ loads ALPS measurements from ALPS HDF5 result files
     
         this function loads results of ALPS simulations ALPS HDF5 result files
         
-        The parameters are:
+        Parameters:
+            files (list): ALPS result files which can be either XML or HDF5 files. XML file names will be changed to the corresponding HDF5 names.
+            what (list): optional argument that is either a string or list of strings, specifying the names of the observables which should be loaded
+            verbose (bool): optional argument that if set to True causes more output to be printed as the data is loaded
         
-        files: a list of ALPS result files which can be either XML or HDF5 files. XML file names will be changed to the corresponding HDF5 names.
-        what: an optional argument that is either a string or list of strings, specifying the names of the observables which should be loaded
-        verbose: an optional boolean argument that if set to True causes more output to be printed as the data is loaded
-        
-        The function returns a list of list of DataSet objects. 
-        The elements of the outer list each correspond to the file names specified as input.
-        The elements of the inner list are each for a different observable.
-        The y-values of the DataSet objects are the measurements and the x-values optionally the labels (indices) of array-valued measurements
+        Returns:
+            a list of list of DataSet objects: loaded measurements.
+            The elements of the outer list each correspond to the file names specified as input.
+            The elements of the inner list are each for a different observable.
+            The y-values of the DataSet objects are the measurements and the x-values optionally the labels (indices) of array-valued measurements
     """
     ll = Hdf5Loader()
     if isinstance(what,str):
       what = [what]
-    return ll.ReadMeasurementFromFile(files,measurements=what,verbose=verbose)
+    return ll.ReadMeasurementFromFile(files,measurements=what,verbose=verbose,respath=respath)
     
     
 def loadEigenstateMeasurements(files,what=None, verbose=False):
@@ -549,17 +592,17 @@ def loadEigenstateMeasurements(files,what=None, verbose=False):
     
         this function loads results of ALPS diagonalization or DMRG simulations from an HDF5 file
         
-        The parameters are:
+        Parameters:
+            files (list): ALPS result files which can be either XML or HDF5 files. XML file names will be changed to the corresponding HDF5 names.
+            what (list): an optional argument that is either a string or list of strings, specifying the names of the observables which should be loaded
+            verbose (bool): an optional argument that if set to True causes more output to be printed as the data is loaded
         
-        files: a list of ALPS result files which can be either XML or HDF5 files. XML file names will be changed to the corresponding HDF5 names.
-        what: an optional argument that is either a string or list of strings, specifying the names of the observables which should be loaded
-        verbose: an optional boolean argument that if set to True causes more output to be printed as the data is loaded
-        
-        The function returns a list of list of (lists of) DataSet objects. 
-        The elements of the outer list each correspond to the file names specified as input.
-        The elements of the next level are different quantum number sectors, if any exists
-        The elements of the inner-most list are each for a different observable.
-        The y-values of the DataSet objects is an array of the measurements in all eigenstates calculated in this sector, and the x-values optionally the labels (indices) of array-valued measurements
+        Returns:
+            list of list of (lists of) DataSet objects: loaded measurements.
+            The elements of the outer list each correspond to the file names specified as input
+            The elements of the next level are different quantum number sectors, if any exists
+            The elements of the inner-most list are each for a different observable
+            The y-values of the DataSet objects is an array of the measurements in all eigenstates calculated in this sector, and the x-values optionally the labels (indices) of array-valued measurements
     """
     ll = Hdf5Loader()
     if isinstance(what,str):
@@ -572,36 +615,65 @@ def loadIterationMeasurements(files,what=None,verbose=False):
       what = [what]
     return ll.ReadDiagDataFromFile(files,measurements=what,loadIterations=True,verbose=verbose)
 
+def loadMPSIterations(files,what=None,verbose=False):
+    ## MPS iterations are stored in: /simulation/iteration/X/results/M with X the sweep index and M the name of the measurement
+    ll = Hdf5Loader()
+    if isinstance(what,str):
+      what = [what]
+    return ll.ReadDiagDataFromFile(files,measurements=what,respath='/simulation',loadIterations=True,verbose=verbose)
 
 def loadSpectra(files,verbose=False):
     """ loads ALPS spectra from ALPS HDF5 result files
     
-        this function loads the spectra calculated in ALPS diagonalization or DMRG simulations from an HDF5 file
+        This function loads the spectra calculated in ALPS diagonalization or DMRG simulations from an HDF5 file.
         
-        The parameters are:
+        Parameters:
+            files (list): ALPS result files which can be either XML or HDF5 files. XML file names will be changed to the corresponding HDF5 names.
+            verbose (bool): optional argument that if set to True causes more output to be printed as the data is loaded.
         
-        files: a list of ALPS result files which can be either XML or HDF5 files. XML file names will be changed to the corresponding HDF5 names.
-        verbose: an optional boolean argument that if set to True causes more output to be printed as the data is loaded
-        
-        The function returns a list of (lists of) DataSet objects. 
-        The elements of the outer list each correspond to the file names specified as input.
-        The elements of the next level are different quantum number sectors, if any exists
-        The y-values of the DataSet objects are the energies in that quantum number sector
+        Returns:
+            list of (lists of) DataSet objects: Loaded spectra.
+            The elements of the outer list each correspond to the file names specified as input.
+            The elements of the next level are different quantum number sectors, if any exists.
+            The y-values of the DataSet objects are the energies in that quantum number sector.
     """
     ll = Hdf5Loader()
     return ll.ReadSpectrumFromFile(files,verbose=verbose)
 
+def loadDMFTIterations(files,observable='G_tau',measurements='0',verbose=False):
+    """ loads ALPS measurements from ALPS HDF5 result files
+    
+        this function loads results of ALPS simulations ALPS HDF5 result files
+        
+        Parameters:
+            files (list): ALPS HDF5 result files.
+            observable (str): optional argument specifying the name of the observables which should be loaded
+            measurements (list): optional argument that is either a string or list of strings, specifying the names of the measurements which should be loaded
+            verbose (bool): optional argument that if set to True causes more output to be printed as the data is loaded
+        
+        Returns:
+            list of list of list of DataSet objects: loaded iteration measurements.
+            The elements of the outer list each correspond to the file names specified as input.
+            The elements of the next level are different iterations.
+            The elements of the inner list contains a DataSet for each measurement.
+            The y-values of the DataSet objects are the measurements and the x-values optionally the labels (indices) of array-valued measurements
+    """
+    ll = Hdf5Loader()
+    if isinstance(measurements,str):
+      measurements = [measurements]
+    return ll.ReadDMFTIterations(files,observable=observable,measurements=measurements,verbose=verbose)
+
 def loadProperties(files,proppath='/parameters',respath='/simulation/results',verbose=False):
     """ loads properties (parameters) of simulations from ALPS HDF5 result files
     
         this function loads the properties (parameters) of ALPS simulations ALPS HDF5 result files
         
-        The parameters are:
+        Parameters:
+            files (list): ALPS result files which can be either XML or HDF5 files. XML file names will be changed to the corresponding HDF5 names.
+            verbose (bool): optional argument that if set to True causes more output to be printed as the data is loaded
         
-        files: a list of ALPS result files which can be either XML or HDF5 files. XML file names will be changed to the corresponding HDF5 names.
-        verbose: an optional boolean argument that if set to True causes more output to be printed as the data is loaded
-        
-        The function returns a list of dicts
+        Returns:
+            list of dicts: properties contained in each file.
     """
     ll = Hdf5Loader()
     res = ll.GetProperties(files,proppath,respath,verbose=verbose)
@@ -614,10 +686,10 @@ def loadObservableList(files,proppath='/parameters',respath='/simulation/results
     """ loads lists of existing measurements from ALPS HDF5 result files
     
         The function returns a list of lists, containing the names of measurements that are stored in the result files 
-        The parameters are:
         
-        files: a list of ALPS result files which can be either XML or HDF5 files. XML file names will be changed to the corresponding HDF5 names.
-        verbose: an optional boolean argument that if set to True causes more output to be printed as the data is loaded
+        Parameters:
+            files (list): ALPS result files which can be either XML or HDF5 files. XML file names will be changed to the corresponding HDF5 names.
+            verbose (bool): optional argument that if set to True causes more output to be printed as the data is loaded
     """
     ll = Hdf5Loader()
     res = ll.GetProperties(files,proppath,respath,verbose=verbose)
@@ -633,7 +705,7 @@ def loadTimeEvolution( flist,globalproppath='/parameters',resroot='/timesteps/',
     for f in flist:
         try:
             #open the file and open the results root group
-            h5file = h5.iArchive(f)
+            h5file = h5.archive(f, 'r')
             #enumerate the subgroups
             L=h5file.list_children(resroot)
             #Create an iterator of length the number of subgroups
@@ -649,7 +721,7 @@ def loadTimeEvolution( flist,globalproppath='/parameters',resroot='/timesteps/',
                     locdata[0][i].props.update(globalprops[0].props)
                 #Extend the total dataset with this data
                 data.extend(locdata)
-        except Exception, e:
+        except Exception as e:
             log(e)
             log( traceback.format_exc())
     return data
