@@ -30,7 +30,19 @@ if sys.platform == 'linux2':
     import DLFCN as dl
     flags = sys.getdlopenflags()
     sys.setdlopenflags(dl.RTLD_NOW|dl.RTLD_GLOBAL)
-    from mpi import *
+    try:
+        try:
+            from .cxx.mpi_c import *
+        except ImportError:
+            from mpi_c import *
+    except ImportError:
+        from boost.mpi import *
     sys.setdlopenflags(flags)
 else:
-    from mpi import *
\ No newline at end of file
+    try:
+        try:
+            from .cxx.mpi_c import *
+        except ImportError:
+            from mpi_c import *
+    except ImportError:
+        from boost.mpi import *
\ No newline at end of file
