@@ -1,3 +1,4 @@
+from __future__ import absolute_import
 # ****************************************************************************
 # 
 # ALPS Project: Algorithms and Libraries for Physics Simulations
@@ -33,22 +34,24 @@ import subprocess
 import platform
 import sys
 import glob
-import numpy as np
+from . import math
+import scipy.stats
 import copy
 
 import pyalps.hdf5 as h5
 
 from pyalps.pytools import convert2xml, hdf5_name_encode, hdf5_name_decode, rng
 import pyalps.pytools # the C++ conversion functions
-from load import loadBinningAnalysis, loadMeasurements,loadEigenstateMeasurements, loadSpectra, loadIterationMeasurements, loadObservableList, loadProperties, in_vistrails, log, Hdf5Loader
-from hlist import deep_flatten, flatten, depth
-from dict_intersect import dict_intersect
-from dataset import DataSet
-from floatwitherror import FloatWithError
-from plot_core import read_xml as readAlpsXMLPlot
-from dict_intersect import *
-from natural_sort import natural_sort
-import alea
+from .load import loadBinningAnalysis, loadMeasurements,loadEigenstateMeasurements, loadSpectra, loadIterationMeasurements, loadMPSIterations, loadObservableList, loadDMFTIterations, loadProperties, in_vistrails, log, Hdf5Loader
+from .hlist import deep_flatten, flatten, depth
+from .dict_intersect import dict_intersect
+from .dataset import DataSet
+from .floatwitherror import FloatWithError
+from .plot_core import read_xml as readAlpsXMLPlot
+from .dict_intersect import *
+from .natural_sort import natural_sort
+from . import alea
+import scipy.interpolate
 
 def make_list(infiles):
     if type(infiles) == list:
@@ -87,46 +90,56 @@ def executeCommandLogged(cmdline,logfile):
     log(cmd)
     return subprocess.call(cmd, shell=True, stdout=open(logfile, 'w'), stderr=subprocess.STDOUT)
 
-def runApplication(appname, parmfile, Tmin=None, Tmax=None, writexml=False, MPI=None, mpirun='mpirun'):
+def runApplication(appname, parmfiles, T=None, Tmin=None, Tmax=None, writexml=False, MPI=None, mpirun='mpirun'):
     """ run an ALPS application 
     
         This function runs an ALPS application. The parameers are:
         
         appname: the name of the application
         parmfile: the name of the main XML input file
-        write_xml: optional parameter, to be set to True if all results should be written to the XML files in addition to the HDF5 files
+        writexml: optional parameter, to be set to True if all results should be written to the XML files in addition to the HDF5 files
+        T: time limit of MC simulation
         Tmin: optional parameter specifying the minimum time between checks whether a MC simulatio is finished
         Tmax: optional parameter specifying the maximum time between checks whether a MC simulatio is finished
         MPI: optional parameter specifying the number of processes to be used in an MPI simulation. MPI is not used if this parameter is left at ots default value  None.
         mpirun: optional parameter giving the name of the executable used to laucnh MPI applications. The default is 'mpirun'
     """
-    cmdline = []
-    if MPI != None:
-        cmdline += [mpirun,'-np',str(MPI)]
-    cmdline += [appname]
-    if MPI != None:
-        cmdline += ['--mpi']
-        if appname in ['sparsediag','fulldiag','dmrg']:
-            cmdline += ['--Nmax','1']
-    cmdline += [parmfile]
-    if Tmin:
-      cmdline += ['--Tmin',str(Tmin)]
-    if Tmax:
-      cmdline += ['--TMax',str(TMax)]
-    if writexml:
-      cmdline += ['--write-xml']
-    return (executeCommand(cmdline),parmfile.replace('.in.xml','.out.xml'))
-    
-def runDMFT(infiles):
+    if isinstance(parmfiles, str):
+      parmfiles = [parmfiles];
+
+    for parmfile in parmfiles:
+      cmdline = []
+      if MPI != None:
+          cmdline += [mpirun,'-np',str(MPI)]
+      cmdline += [appname]
+      if MPI != None:
+          cmdline += ['--mpi']
+          if appname in ['sparsediag','fulldiag','dmrg']:
+              cmdline += ['--Nmax','1']
+      cmdline += [parmfile]
+      if T:
+        cmdline += ['-T',str(T)]
+      if Tmin:
+        cmdline += ['--Tmin',str(Tmin)]
+      if Tmax:
+        cmdline += ['--TMax',str(Tmax)]
+      if writexml:
+        cmdline += ['--write-xml']
+      if parmfile.find('.xml') != -1:
+        return (executeCommand(cmdline),parmfile.replace('.in.xml','.out.xml'))  # no iteration for xml i/o
+      if parmfile.find('.h5') != -1:
+        executeCommand(cmdline);
+   
+
+def runDMFT(infiles,apppath=''):
     """ run the ALPS DMFT application 
     
         The ALPS DMFT application does not (yet) use the standard ALPS input files and scheduler. Thus there is a separate function to call it. 
-        This function takes only one parameter, the lost of input files.
+        This function takes one mandatory parameter: a single input file or a list of input files.
+        Optional parameter apppath allows setting the path to the binary.
     """
     appname='dmft'
-    cmdline = [appname]
-    cmdline += make_list(infiles)
-    return (executeCommand(cmdline))
+    return (executeCommand([apppath+appname] + make_list(infiles)))
     
 def evaluateLoop(infiles, appname='loop', write_xml=False):
     """ evaluate results of the looper QMC application 
@@ -137,7 +150,7 @@ def evaluateLoop(infiles, appname='loop', write_xml=False):
     """
     cmdline = [appname,'--evaluate']
     if write_xml:
-      cmdline += ['--write_xml']
+      cmdline += ['--write-xml']
     cmdline += make_list(infiles)
     return executeCommand(cmdline)
 
@@ -152,7 +165,7 @@ def evaluateSpinMC(infiles, appname='spinmc_evaluate', write_xml=False):
     """
     cmdline = [appname]
     if write_xml:
-      cmdline += ['--write_xml']
+      cmdline += ['--write-xml']
     cmdline += make_list(infiles)
     return executeCommand(cmdline)
 
@@ -258,7 +271,9 @@ def evaluateFulldiagVersusH(infiles, appname='fulldiag_evaluate', DELTA_H=None,
        
 def inVistrails():
     """ returns True if called from within VisTrails """
-    return in_vistrails
+    #return in_vistrails
+    return (sys.prefix.find('VisTrails') != -1)
+
     
 def xslPath():
     """ return the path to the ALPS.xsl stylesheet """
@@ -266,7 +281,7 @@ def xslPath():
       if platform.system()=='Darwin':
         return os.path.join(sys.exec_prefix,'../Resources/lib/xml/ALPS.xsl')
       if platform.system()=='Windows':
-        return os.path.join(sys.exec_prefix,'..','lib','xml','ALPS.xsl')
+        return os.path.join(sys.exec_prefix,'..','vistrails','lib','xml','ALPS.xsl')
     return pyalps.pytools.search_xml_library_path("ALPS.xsl")
     
     
@@ -277,7 +292,7 @@ def copyStylesheet(dir):
       shutil.copyfile(xslPath(), target)
 
 def writeTaskXMLFile(filename,parms):
-    f = file(filename,'w')
+    f = open(filename,'w')
     f.write('<?xml version="1.0" encoding="UTF-8"?>\n')
     f.write('<?xml-stylesheet type="text/xsl" href="ALPS.xsl"?>\n')
     f.write('<SIMULATION xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:noNamespaceSchemaLocation="http://xml.comp-phys.org/2003/8/QMCXML.xsd">\n')
@@ -296,6 +311,55 @@ def generateSeed():
     baseseed = ((baseseed << 10) | (baseseed >> 22));
     return baseseed
 
+def writeInputH5Files(filename_,params_list):
+  """ This function writes the H5 input files for ALPS (NGS)
+
+      The parameters are:
+      1. filename_   : the base file name of the H5 files that will be written
+      2. params_list : a list of python dicts containing the simulation parameters
+
+      Ping Nang MA 
+  """
+  input_files_ = [];
+  for index in range(len(params_list)):
+    if filename_.find('.in.h5') != -1:
+      this_filename_ = filename_; 
+    else:
+      this_filename_ = filename_ + '.task' + str(index+1) + '.in.h5';
+    input_files_.append(this_filename_);
+    oar = pyalps.hdf5.archive(this_filename_,'w');
+    for key in params_list[index].keys():
+      oar['/parameters/' + key] = params_list[index][key]
+    del oar;
+  return input_files_;
+
+def getInputH5Files(prefix='*',pattern='.task*.in.h5'):
+    return glob.glob(prefix+pattern);
+
+
+def getParameters(infiles_):
+   """ This function extracts the parameters from the H5 input files for ALPS (NGS)
+
+       1. infiles_ : either a list of filenames, or just one filename, containing NGS parameters object.
+       
+       Will be returned as a list of python dicts (parameters).
+
+       Ping Nang MA
+   """
+   if isinstance(infiles_, str):
+     infiles_ = [infiles_];
+
+   params = [];
+   for infile_ in infiles_:
+     iar = pyalps.hdf5.archive(infile_);
+     params_dict = {};
+     for key in iar.list_children('/parameters'):
+       params_dict[key] = iar['/parameters/' + key];
+     params.append(params_dict);
+
+   return params;
+
+
 def writeInputFiles(fname,parms, baseseed=None):
     """ This function writes the XML input files for ALPS
     
@@ -308,7 +372,7 @@ def writeInputFiles(fname,parms, baseseed=None):
     """
     dirname = os.path.dirname(fname)
     base_name = os.path.basename(fname)
-    f = file(fname+'.in.xml','w')
+    f = open(fname+'.in.xml','w')
     f.write('<?xml version="1.0" encoding="UTF-8"?>\n')
     f.write('<?xml-stylesheet type="text/xsl" href="ALPS.xsl"?>\n')
     f.write('<JOB xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:noNamespaceSchemaLocation="http://xml.comp-phys.org/2003/8/job.xsd">\n')
@@ -317,7 +381,7 @@ def writeInputFiles(fname,parms, baseseed=None):
     bits = 31;
     n = len(parms)
     while n>0:
-      n /= 2
+      n //= 2
       bits -= 1
 
     if baseseed == None:
@@ -328,7 +392,7 @@ def writeInputFiles(fname,parms, baseseed=None):
       count += 1
       if not 'SEED' in p:
         seed = baseseed
-        for j in range(0,32/bits+1):
+        for j in range(0,32//bits+1):
           seed ^= ((count-1) << (j * bits))
           seed &= ((1<<30) | ((1<<30)-1))
           p['SEED'] = seed
@@ -356,7 +420,7 @@ def writeParameterFile(fname,parms):
           filename: the name of the parameter file to be written
           parms: the parameter dict
     """
-    f = file(fname,'w')
+    f = open(fname,'w')
     for key in parms:
       value = parms[key]
       if type(value) == str:
@@ -366,15 +430,33 @@ def writeParameterFile(fname,parms):
     f.close()
     return fname
 
+def input2output(infile):
+    if   infile.find('.in.h5') != -1:
+      outfile = infile.replace('.in.h5', '.out.h5');
+    elif infile.find('.out.h5') != -1:
+      outfile = infile;
+    elif infile.find('.h5') != -1:
+      outfile = infile.replace('.h5', '.out.h5');
+    elif infile.find('.in.xml') != -1:
+      outfile = infile.replace('.in.xml', '.out.xml');
+    elif infile.find('.out.xml') != -1:
+      outfile = infile;
+    elif infile.find('.xml') != -1:
+      outfile = infile.replace('.xml', '.out.xml');
+    else:
+      outfile = infile;
+    return outfile;
+
 
 def recursiveGlob(dirname,pattern):
     ret = glob.glob(os.path.join(dirname, pattern))
     for d in os.listdir(dirname):
+        d = os.path.join(dirname, d)
         if os.path.isdir(d):
-            ret += recursiveGlob(os.path.join(dirname, d), pattern)
+            ret += recursiveGlob(d, pattern)
     return ret
-    
-def getResultFiles(dirname='.',pattern=None,prefix=None):
+
+def getResultFiles(dirname='.',pattern=None,prefix=None,format=None):
     """ get all result files matching the given pattern or prefix 
     
         This function returns a list of all ALPS result files matching a given pattern, starting recursively from a given directory.
@@ -393,18 +475,118 @@ def getResultFiles(dirname='.',pattern=None,prefix=None):
       raise Exception("Cannot define both prefix and pattern")
     if prefix == None: prefix = '*'
     if pattern == None:
-      pattern = prefix+'.task*.out.xml'
-      res=recursiveGlob(dirname, pattern)
-      if len(res)==0:
-        pattern = prefix+'*.h5'
+      if format == None:
+        pattern = prefix+'.task*.out.xml'
         res=recursiveGlob(dirname, pattern)
+        if len(res)==0:
+          pattern = prefix+'*.task*.out.h5'
+          res=recursiveGlob(dirname, pattern)
+          if len(res)==0:
+            pattern = prefix+'*h5'
+            res=recursiveGlob(dirname, pattern)
+      else:
+        if   format == 'xml':
+          pattern = prefix+'.task*.out.xml'
+          res=recursiveGlob(dirname, pattern)
+        elif format == 'hdf5':
+          pattern = prefix+'.task*.out.h5'
+          res=recursiveGlob(dirname, pattern)
+          if len(res)==0:
+            pattern = prefix+'*h5'
+            res=recursiveGlob(dirname, pattern)
     else:
       res = recursiveGlob(dirname, pattern)
     replicas=recursiveGlob(dirname, prefix+'*replica*h5')
     res += replicas
     return res
 
-def collectXY(sets,x,y,foreach=[]):
+def loadTimeSeries(outfile, observable=None):
+  if isinstance(outfile,str):
+    if isinstance(observable,str):
+      outfile = outfile.replace('.xml','.h5');
+
+      ar = pyalps.hdf5.archive(outfile);
+      return ar['/simulation/results'][observable]['timeseries']['data']
+
+def getMeasurements(outfiles_, observable=None, includeLog=False):
+  measurements = [];
+
+  if isinstance(outfiles_,str):
+    outfiles_ = [outfiles_];
+
+  for outfile in outfiles_:
+    outfile = outfile.replace('.xml','.h5');
+    ar = pyalps.hdf5.archive(outfile);
+    if isinstance(observable, str):
+      measurements.append(ar['/simulation/results'][observable])
+    
+    del ar;
+
+  return measurements;
+
+def checkSteadyState(sets=None, outfile=None, observable=None, confidenceInterval=0.6827, includeLog=False):
+  if sets != None:
+    results = []
+    for iset in flatten(sets):
+      iset.props['checkSteadyState'] = checkSteadyState(outfile=iset.props['filename'], observable=iset.props['observable'], confidenceInterval=confidenceInterval, includeLog=True);
+      results.append(iset); 
+    return results 
+
+  else:
+    ts  = pyalps.loadTimeSeries(outfile, observable);  ### y
+    N   = ts.size;
+    idx = scipy.linspace(1, N, N);                     ### x
+
+    beta1 = scipy.polyfit(idx, ts, 1)[0];              ### slope
+    
+    ts_std    = np.std(ts, ddof=1);                          ### unbiased estimate of standard deviation in y
+    beta1_std = math.sqrt((12.*ts_std*ts_std)/(N * (N*N-1)));   ### unbiased estimate of standard deviation in slope
+
+    z  = abs(beta1/beta1_std);
+    z0 = scipy.stats.norm.ppf((1.-confidenceInterval) + 0.5*(confidenceInterval));   
+    
+    result = z < z0;
+
+    if not includeLog:
+      return {'value': result};
+    else:
+      return {'value': result, 'props':{ 'outfile': outfile, 'observable': observable}, 'statistics': {'beta1' : {'value' : beta1, 'std' : beta1_std}, 'confidenceInterval' : confidenceInterval, 'z' : z, 'z0' : z0}};
+
+def checkConvergence(sets):
+  results = []
+  for iset in flatten(sets):
+    ar = pyalps.hdf5.archive(iset.props['filename']) 
+    if ar['/simulation/results'][iset.props['observable']]['mean']['error_convergence'] == 0:
+      result = True;
+    else:
+      result = False;
+    del ar;
+    iset.props['checkConvergence'] = result
+    results.append(iset);
+  return results;
+
+def sendmail(recipients, sender=None, message='', subject='', attachment=None):
+  message = 'Automatic email message from ALPS.\nDo not reply.\n\n' + str(message);
+  subject = 'Automatic email message from ALPS. ' + str(subject); 
+
+  command = ['echo', message, '|', 'mail', '-s', subject];
+  if sender != None:
+    command += ['-r', sender];
+  if attachment != None:
+    command += ['-a', attachment]; 
+  command += [recipients];
+
+  return pyalps.executeCommand(command);
+
+def extract(appname, source, target):
+  cmdline = [appname];
+  cmdline += [source];
+  cmdline += [target];
+  executeCommand(cmdline);
+  return; 
+
+
+def collectXY(sets,x,y,foreach=[],ignoreProperties=False):
       """ collects specified data from a list of DataSet objects
          
           this function is used to collect data from a list of DataSet objects, to prepare plots or evaluation. The parameters are:
@@ -413,21 +595,20 @@ def collectXY(sets,x,y,foreach=[]):
             x:       the name of the property or measurement to be used as x-value of the collected results 
             y:       the name of the property or measurement to be used as y-value of the collected results 
             foreach: an optional list of properties used for grouping the results. A separate DataSet object is created for each unique set of values of the specified parameers.
+            ignoreProperties: setting ignoreProperties=True prevents collectXY() from collecting properties.
             
           The function returns a list of DataSet objects.
       """
       foreach_sets = {}
       for iset in flatten(sets):
-          if iset.props['observable'] != y:
+          if iset.props['observable'] != y and not y in iset.props:
               continue
           
           fe_par_set = tuple((iset.props[m] for m in foreach))
-          
           if fe_par_set in foreach_sets:
               foreach_sets[fe_par_set].append(iset)
           else:
               foreach_sets[fe_par_set] = [iset]
-      
       for k,v in foreach_sets.items():
           common_props = dict_intersect([q.props for q in v])
           res = DataSet()
@@ -439,17 +620,27 @@ def collectXY(sets,x,y,foreach=[]):
           res.props['ylabel'] = y
           
           for data in v:
-              if len(data.y)>1:
+              if data.props['observable'] == y:
+                  if len(data.y)>1:
+                      res.props['line'] = '.'
+                  xvalue = np.array([data.props[x] for i in range(len(data.y))])
+                  if len(res.x) > 0 and len(res.y) > 0:
+                      res.x = np.concatenate((res.x, xvalue ))
+                      res.y = np.concatenate((res.y, data.y))
+                  else:
+                      res.x = xvalue
+                      res.y = data.y
+              elif not ignoreProperties:
                   res.props['line'] = '.'
-              xvalue = np.array([data.props[x] for i in range(len(data.y))])
-              if len(res.x) > 0 and len(res.y) > 0:
-                  res.x = np.concatenate((res.x, xvalue ))
-                  res.y = np.concatenate((res.y, data.y))
-              else:
-                  res.x = xvalue
-                  res.y = data.y
+                  xvalue = np.array([ data.props[x] ])
+                  if len(res.x) > 0 and len(res.y) > 0:
+                      res.x = np.concatenate((res.x, xvalue ))
+                      res.y = np.concatenate((res.y, np.array([ data.props[y] ])))
+                  else:
+                      res.x = xvalue
+                      res.y = np.array([ data.props[y] ])
           
-          order = np.argsort(res.x) #, kind = 'mergesort')
+          order = np.argsort(res.x, kind = 'mergesort')
           res.x = res.x[order]
           res.y = res.y[order]
           res.props['label'] = ''
@@ -457,7 +648,96 @@ def collectXY(sets,x,y,foreach=[]):
               res.props['label'] += '%s = %s ' % (foreach[im], k[im])
           
           foreach_sets[k] = res
-      return foreach_sets.values()
+      return list(foreach_sets.values())
+
+def ResultsToXY(sets,x,y,foreach=[]):
+    """ combines observable x and y to build a list of DataSet with y vs x
+ 
+    this function is used to collect data from a hierarchy of DataSet objects, to prepare plots or evaluation.
+    the inner-most list has to contain one DataSet with props['observable'] = x and one props['observable'] = y,
+    this will be the pair x-y used in the collection.
+
+    The parameters are:
+      sets:    hierarchy of datasets where the inner-most list must contain to pair x-y
+      x:       the name of the observable to be used as x-value of the collected results 
+      y:       the name of the observable to be used as y-value of the collected results 
+      foreach: an optional list of properties used for grouping the results. A separate DataSet object is created for each unique set of values of the specified parameers.
+
+    The function returns a list of DataSet objects.
+    """
+    
+    dd = depth(sets)
+    if dd < 2:
+        raise Exception('The input hierarchy does not provide a unique pair x-y. The input structure has to be a list of lists as minimum. pyalps.groupSets might help you.')
+    
+    hgroups = flatten(sets, fdepth=-1)
+    
+    foreach_sets = {}
+    for gg in hgroups:
+        xset = None
+        yset = None
+        for d in gg:
+            if d.props['observable'] == x:
+                xset = d
+            if d.props['observable'] == y:
+                yset = d
+        if xset is None or yset is None:
+            continue
+        
+        common_props = dict_intersect([d.props for d in gg])
+        fe_par_set = tuple((common_props[m] for m in foreach))
+        
+        if not fe_par_set in foreach_sets:
+            foreach_sets[fe_par_set] = DataSet()
+            foreach_sets[fe_par_set].props = common_props
+            foreach_sets[fe_par_set].props['xlabel'] = x
+            foreach_sets[fe_par_set].props['ylabel'] = y
+        
+        if len(xset.y) == len(yset.y):
+            foreach_sets[fe_par_set].x = np.concatenate((foreach_sets[fe_par_set].x, xset.y))
+            foreach_sets[fe_par_set].y = np.concatenate((foreach_sets[fe_par_set].y, yset.y))
+        elif len(xset.y) == 1:
+            foreach_sets[fe_par_set].x = np.concatenate((foreach_sets[fe_par_set].x, np.array( [xset.y[0]]*len(yset.y) )))
+            foreach_sets[fe_par_set].y = np.concatenate((foreach_sets[fe_par_set].y, yset.y))
+    
+    for k, res in foreach_sets.items():
+        order = np.argsort(res.x, kind = 'mergesort')
+        res.x = res.x[order]
+        res.y = res.y[order]
+        res.props['label'] = ''
+        for p in foreach:
+            res.props['label'] += '%s = %s ' % (p, res.props[p])
+        
+    return list(foreach_sets.values())
+
+def paramsAtFixedY(sets,x,y,fixedY,foreach=[]):
+  XYs = collectXY(sets,x,y,foreach);
+
+  params = [];
+  for XY in XYs:
+    param = XY.props;
+    xlabel = param['xlabel'];
+    del param['observable'];
+    del param['hdf5_path'];
+    del param['label'];
+    del param['xlabel'];
+    del param['ylabel'];
+
+    x = XY.x;
+    y = [y.mean for y in XY.y];
+
+    f = scipy.interpolate.interp1d(y,x);
+
+    if isinstance(fixedY, int) or isinstance(fixedY, float):
+      fixedY = [fixedY];
+    
+    for this_fixedY in fixedY:
+      xnew = f(this_fixedY);
+      this_param = copy.deepcopy(param);
+      this_param[xlabel] = float(xnew);
+      params.append(this_param);
+
+  return params;
 
 def groupSets(groups, for_each = []):
     """ groups a list of DataSet objects into a list of lists
@@ -488,7 +768,7 @@ def groupSets(groups, for_each = []):
             else:
                 for_each_sets[fe_par_set] = [iset]
 
-        hgroups[idx] = for_each_sets.values()
+        hgroups[idx] = list(for_each_sets.values())
 
     if dd > 1:
         return groups
@@ -526,9 +806,9 @@ def save_parameters(filename, parms):
           filename: the name of the HDF5 file
           parms: the parameter dict
     """
-    f1=h5.oArchive(filename)
+    f1=h5.archive(filename, 'w')
     for key in parms.keys():
-        f1.write('/parameters/'+key,parms[key])
+        f1['/parameters/'+key] = parms[key]
 
 def runTEBD(infileList):
     """ run a TEBD application """
@@ -638,49 +918,55 @@ def writeTEBDfiles(parmsList, fileName):
         #check for conserved quantum numbers
         if 'CONSERVED_QUANTUMNUMBERS' in parms:
             if str(parms['MODEL'])=='spin':
-                if parms['CONSERVED_QUANTUMNUMBERS']=='Sz':
+                if parms['CONSERVED_QUANTUMNUMBERS']=='Sz_total':
                     systemSettingsString+=", qswitch=.true."
-                    systemSettingsString+=", qType='Sz'"
+                    systemSettingsString+=", qType='Sz_total'"
                 else:
-                    raise Exception("Only Sz may be conserved for spin models!")
+                    raise Exception("Only Sz_total may be conserved for spin models!")
                     systemSettingsString+=", qswitch=.false."
-                    systemSettingsString+=", qType='Sz'"
+                    systemSettingsString+=", qType='Sz_total'"
             else:
-                if parms['CONSERVED_QUANTUMNUMBERS']=='N':
+                if parms['CONSERVED_QUANTUMNUMBERS']=='N_total':
                     systemSettingsString+=", qswitch=.true."
-                    systemSettingsString+=", qType='N'"
+                    systemSettingsString+=", qType='N_total'"
                 else:
-                    raise Exception("Only N may be conserved for particle models!")
+                    raise Exception("Only N_total may be conserved for particle models!")
                     systemSettingsString+=", qswitch=.false."
-                    systemSettingsString+=", qType='N'"
+                    systemSettingsString+=", qType='N_total'"
         else:
             systemSettingsString+=", qswitch=.false."
-            systemSettingsString+=", qType='Sz'"
+            systemSettingsString+=", qType='Sz_total'"
 
         #check for value of conserved quantum number
         #Sz
-        if 'Sz' in parms:
+        if 'Sz_total' in parms:
             if str(parms['MODEL'])=='spin':
                 #Add L*S to this number to convert it to an integer appropriate for TEBD
-                parms['Sz']=float(parms['L'])*float(parms['local_S'])-float(parms['Sz'])
+                parms['Sz_total']=float(parms['L'])*float(parms['local_S'])-float(parms['Sz_total'])
                 #convert to an integer-complain if it doesn't work
-                if int(parms['Sz'])==float(parms['Sz']):
-                    systemSettingsString+=", totQ="+str(int(parms['Sz']))
+                if int(parms['Sz_total'])==float(parms['Sz_total']):
+                    systemSettingsString+=", totQ="+str(int(parms['Sz_total']))
                 else:
-                    raise Exception("Invalid Sz encountered!")
+                    raise Exception("Invalid Sz_total encountered!")
                     systemSettingsString+=", totQ=0"
             else:
-                raise Exception("Sz only conserved for spin models!")
+                raise Exception("Sz_total only conserved for spin models!")
                 systemSettingsString+=", totQ=0"
         #N
-        elif 'N' in parms:
+        elif 'N_total' in parms:
             if str(parms['MODEL'])=='spin':
-                raise Exception("N only conserved for particle models!")
+                raise Exception("N_total only conserved for particle models!")
                 systemSettingsString+=", totQ=0"
             else:
-                systemSettingsString+=", totQ="+str(int(parms['N']))
+                systemSettingsString+=", totQ="+str(int(parms['N_total']))
         else:
-            systemSettingsString+=", totQ=0"
+            if 'INITIAL_STATE' in parms:
+                if parms['INITIAL_STATE']=='kink':
+                    systemSettingsString+=", totQ=0"
+                else:
+                    raise Exception("Value of conserved quantity not specified!  Use N_total for particles or Sz_total for magnetization!")
+            else :
+                raise Exception("Value of conserved quantity not specified!  Use N_total for particles or Sz_total for magnetization!")
 
         #check for openmp threading
         if 'NUM_THREADS' in parms:
@@ -1220,8 +1506,9 @@ def mergeDataSets(dsets):
         if len(d.y) != len(merged.y): raise ValueError('cannot merge datasets: y shape mismatch')
         if isinstance(merged.y,alea.MCVectorData):
             merged.y.merge(d.y)
-        for i in range(len(merged.y)):
-            merged.y[i].merge(d.y[i])
+        else:
+            for i in range(len(merged.y)):
+                merged.y[i].merge(d.y[i])
     merged.props = props
     return merged
 
@@ -1235,7 +1522,7 @@ def mergeMeasurements(measurements):
     merged = [mergeDataSets(v) for v in byname.values()]
     return merged
 
-def mergeMeasurementsFromFiles(files,respath='/simulation/realizations/0/clones/0/results'):
+def mergeMeasurementsFromFiles(files,respath='/simulation/realizations/0/clones/0/measurements'):
     ll = Hdf5Loader()
     meas = ll.ReadMeasurementFromFile(files,respath=respath)
     return mergeMeasurements(meas)
@@ -1248,11 +1535,11 @@ def saveMeasurements(measurements,outfile,respath='/simulation/results'):
         elif isinstance(m.y,np.ndarray) and isinstance(m.y[0],alea.MCScalarData):
             m.y[0].save(outfile,path)
         elif isinstance(m.y,FloatWithError):
-            h5f = h5.oArchive(fn)
-            h5f.write(path+'/mean/value',np.array(m.y.mean))
-            h5f.write(path+'/mean/error',np.array(m.y.error))
+            h5f = h5.archive(fn, 'w')
+            h5f[path+'/mean/value'] = np.array(m.y.mean)
+            h5f[path+'/mean/error'] = np.array(m.y.error)
             try:
-                h5f.write(path+'/jackknife',np.array(m.jacks))
+                h5f[path+'/jackknife'] = np.array(m.jacks)
             except AttributeError:
                 pass
 
