@@ -29,7 +29,7 @@
 *
 *****************************************************************************/
 
-/* $Id: simpleobsdata.h 6003 2012-02-22 08:58:15Z tamama $ */
+/* $Id: simpleobsdata.h 7566 2015-04-02 07:28:20Z wistaria $ */
 
 #ifndef ALPS_ALEA_SIMPLEOBSDATA_H
 #define ALPS_ALEA_SIMPLEOBSDATA_H
@@ -383,7 +383,7 @@ SimpleObservableData<T>::SimpleObservableData(std::istream& infile, const XMLTag
 
 inline double text_to_double(const std::string& val)
 {
-  return ((val=="NaN" || val=="nan" || val=="NaNQ") ? alps::nan() :
+  return ((val=="NaN" || val=="nan" || val=="NaNQ" || val == "-nan") ? alps::nan() :
           ((val=="INF" || val=="Inf" || val == "inf") ? alps::inf() :
            ((val=="-INF" || val=="-Inf" || val == "-inf") ? alps::ninf() :
             boost::lexical_cast<double, std::string>(val))));
@@ -679,9 +679,9 @@ template <class T>
 template <class OP>
 void SimpleObservableData<T>::transform_linear(OP op)
 {
+  fill_jack();
   mean_ = op(mean_);
   std::transform(values_.begin(), values_.end(), values_.begin(), op);
-  fill_jack();
   std::transform(jack_.begin(), jack_.end(), jack_.begin(), op);
 }
 
@@ -689,6 +689,7 @@ template <class T>
 template <class OP>
 void SimpleObservableData<T>::transform(OP op)
 {
+  fill_jack();
   valid_ = false;
   nonlinear_operations_ = true;
   changed_ = true;
@@ -698,7 +699,6 @@ void SimpleObservableData<T>::transform(OP op)
   std::transform(values_.begin(), values_.end(), values_.begin(),boost::lambda::_1/double(bin_size()));
   std::transform(values_.begin(), values_.end(), values_.begin(), op);
   std::transform(values_.begin(), values_.end(), values_.begin(),boost::lambda::_1*double(bin_size()));
-  fill_jack();
   std::transform(jack_.begin(), jack_.end(), jack_.begin(), op);
 }
 
@@ -773,6 +773,7 @@ template <class T> template <class X>
 void SimpleObservableData<T>::divide(const X& x)
 {
   if (count()) {
+    fill_jack();
     error_ = x *error_/mean_/mean_;
     has_variance_ = false;
     values2_.clear();
@@ -780,7 +781,6 @@ void SimpleObservableData<T>::divide(const X& x)
     changed_ = true;
     mean_ = x/mean_;
     double f = bin_size() * bin_size();
-    fill_jack();
     std::transform(values_.begin(), values_.end(), values_.begin(), (x*f)/boost::lambda::_1);
     std::transform(jack_.begin(), jack_.end(), jack_.begin(), x/boost::lambda::_1);
     nonlinear_operations_ = true;
@@ -879,8 +879,15 @@ template <class T> SimpleObservableData<T> & SimpleObservableData<T>::operator<<
         std::copy(tmp.values2_.begin(), tmp.values2_.end(),
                   std::back_inserter(values2_));
       }
-      if (max_bin_number_ && max_bin_number_ < bin_number())
-        set_bin_number(max_bin_number_);
+      if (max_bin_number_ && max_bin_number_ < bin_number()) {
+        if (run.count() >= 4 * binsize_) {
+          set_bin_number(max_bin_number_);
+        } else {
+          // stop increasing bin_size, otherwise bin_size will exceed the measurement count of each run
+          // and the measurements in the following clons will not be merged - 2015-04-02 Synge
+          max_bin_number_ = 0;
+        }
+      }
     }
   }
   return *this;
