@@ -26,13 +26,14 @@
 *
 *****************************************************************************/
 
-/* $Id: graph_helper.h 5478 2011-04-07 21:57:30Z dolfim $ */
+/* $Id: graph_helper.h 7707 2016-05-24 07:57:52Z hehn $ */
 
 #ifndef ALPS_LATTICE_GRAPHHELPER_H
 #define ALPS_LATTICE_GRAPHHELPER_H
 
 #include <alps/lattice/latticelibrary.h>
 #include <alps/lattice/disorder.h>
+#include <alps/lattice/coordinategraph.h>
 #include <alps/lattice/graph_traits.h>
 #include <alps/lattice/parity.h>
 #include <alps/lattice/propertymap.h>
@@ -78,37 +79,40 @@ void throw_if_xyz_defined(const Parameters& p, const G& graph)
       "x, y or z is predefined as parameter and used as coordinate"));
 }
 
+
 template <class G>
 Parameters coordinate_as_parameter(const G& graph,
-  const typename boost::graph_traits<G>::edge_descriptor& edge)
+  const typename boost::graph_traits<G>::vertex_descriptor& source,
+  const typename boost::graph_traits<G>::vertex_descriptor& target)
 {
   Parameters parms;
   unsigned int dim = detail::graph_dimension_helper<
     has_property<dimension_t, G>::graph_property>::dimension(graph);
   switch (dim) {
   case 3 :
-    parms["z"] = 0.5 * (boost::get(coordinate_t(), graph,
-                                   boost::source(edge, graph))[2] +
-                        boost::get(coordinate_t(), graph,
-                                   boost::target(edge, graph))[2]);
+    parms["z"] = 0.5 * (boost::get(coordinate_t(), graph, source)[2] +
+                        boost::get(coordinate_t(), graph, target)[2]);
     // continue
   case 2 :
-    parms["y"] = 0.5 * (boost::get(coordinate_t(), graph,
-                                   boost::source(edge, graph))[1] +
-                        boost::get(coordinate_t(), graph,
-                                   boost::target(edge, graph))[1]);
+    parms["y"] = 0.5 * (boost::get(coordinate_t(), graph, source)[1] +
+                        boost::get(coordinate_t(), graph, target)[1]);
     // continue
   case 1 :
-    parms["x"] = 0.5 * (boost::get(coordinate_t(), graph,
-                                   boost::source(edge, graph))[0] +
-                        boost::get(coordinate_t(), graph,
-                                   boost::target(edge, graph))[0]);
+    parms["x"] = 0.5 * (boost::get(coordinate_t(), graph, source)[0] +
+                        boost::get(coordinate_t(), graph, target)[0]);
   default :
     break;
   }
   return parms;
 }
 
+template <class G>
+Parameters coordinate_as_parameter(const G& graph,
+  const typename boost::graph_traits<G>::edge_descriptor& edge)
+{
+  return coordinate_as_parameter(graph, boost::source(edge, graph), boost::target(edge, graph));
+}
+
 template <class G>
 Parameters coordinate_as_parameter(const G& graph,
   const typename boost::graph_traits<G>::vertex_descriptor& vertex)
@@ -535,7 +539,11 @@ public:
 
   std::vector<std::string> momenta_labels(int precision = 0) const
   {
-      return l_.momenta_labels(precision);
+    std::vector<std::string> labels;
+    momentum_iterator it, end;
+    for (boost::tie(it,end) = momenta(); it != end; ++it)
+      labels.push_back(alps::coordinate_to_string(this->momentum(*it), precision));
+    return labels;
   }
 
   std::vector<std::string> distance_labels(int precision = 0) const
@@ -696,7 +704,7 @@ G* graph_helper<G>::make_graph(const Parameters& parms)
     have_lattice_=true;
   }
   else{
-    boost::throw_exception(std::runtime_error("could not find graph/lattice specified in parameters"));
+    boost::throw_exception(std::runtime_error("could not find graph/lattice specified in parameters: name was: \'"+name+"\'"));
     g=NULL;
   }
   return g;
