@@ -26,7 +26,7 @@
 *
 *****************************************************************************/
 
-/* $Id: hypercubic.h 4704 2010-07-08 17:41:12Z troyer $ */
+/* $Id: hypercubic.h 7707 2016-05-24 07:57:52Z hehn $ */
 
 #ifndef ALPS_LATTICE_HYPERCUBIC_H
 #define ALPS_LATTICE_HYPERCUBIC_H
@@ -34,6 +34,7 @@
 #include <alps/config.h>
 #include <alps/lattice/lattice.h>
 #include <alps/lattice/coordinate_traits.h>
+#include <alps/lattice/boundary.h>
 
 #include <alps/utility/vectorio.hpp>
 #include <alps/numeric/vector_functions.hpp>
@@ -134,7 +135,6 @@ public:
 
     const cell_iterator& operator++() {
       typedef typename coordinate_traits<offset_type>::iterator offset_iterator;
-      typedef typename coordinate_traits<offset_type>::const_iterator const_offset_iterator;
       offset_iterator offit, offend;
       boost::tie(offit,offend)=coordinates(offset_);
       int d=0;
@@ -368,11 +368,6 @@ public:
     momentum_iterator(cell_iterator it=cell_iterator()) : cell_iterator(it), valid_(false) {}
     const vector_type& operator*() const { set_k(); return k_; }
     const vector_type* operator->() const { set_k(); return &k_; }
-    std::complex<double> phase(const vector_type& pos) const {
-      set_k();
-      double phase=numeric::scalar_product(k_,pos);
-      return std::complex<double>(std::cos(phase),std::sin(phase));
-    }
     const momentum_iterator& operator++() { 
       valid_=false; 
       cell_iterator::operator++(); 
