@@ -30,8 +30,6 @@
 
 /* $Id: pyalea.cpp 3520 2010-04-09 16:49:53Z tamama $ */
 
-#define PY_ARRAY_UNIQUE_SYMBOL pyalea_PyArrayHandle
-
 #include <alps/python/make_copy.hpp>
 #include <alps/python/numpy_array.hpp>
 #include <alps/alea/detailedbinning.h>
@@ -47,8 +45,6 @@
 #include <boost/random/uniform_01.hpp>
 #include <boost/python/suite/indexing/vector_indexing_suite.hpp>
 
-#include <numpy/arrayobject.h>
-
 #include <vector>
 #include <string>
 
@@ -77,29 +73,29 @@ namespace alps {
           return obs.representation();
       }
       
-      boost::python::numeric::array mean() const 
+      alps::python::numpy::array mean() const 
       {
           return alps::python::numpy::convert2numpy(obs.mean());
       }
       
-      boost::python::numeric::array error() const 
+      alps::python::numpy::array error() const 
       {
           return alps::python::numpy::convert2numpy(obs.error());
       }
       
-      boost::python::numeric::array tau() const 
+      alps::python::numpy::array tau() const 
       {
           return alps::python::numpy::convert2numpy(obs.tau());
       }
 
-     boost::python::numeric::array variance() const 
+      alps::python::numpy::array variance() const 
       {
           return alps::python::numpy::convert2numpy(obs.variance());
       }
       
       void save(std::string const & filename) const {
           hdf5::archive ar(filename, "a");
-          ar << make_pvp("/simulation/results/"+obs.representation(), obs);
+          ar["/simulation/results/"+obs.representation()] << obs;
       }
 
       typename T::count_type count() const 
@@ -134,7 +130,7 @@ namespace alps {
 
     #define ALPS_ALEA_FUNCTION_NUMPY_WRAPPER(function_name) \
     template <class T> \
-    boost::python::numeric::array function_name## _wrapper ( const T& arg1 ) { \
+    alps::python::numpy::array function_name## _wrapper ( const T& arg1 ) { \
       return alps::python::numpy::convert(function_name( arg1 )) ;  \
     } 
 
@@ -301,8 +297,6 @@ ALPS_PY_EXPORT_SIMPLEOBSERVABLE(RealTimeSeriesObservable,timeseries_observable_d
 
 #undef ALPS_PY_EXPORT_SIMPLEOBSERVABLE
 
-
-
 // mcanalyze export
 
 #define QUOTEME(x) #x
@@ -330,8 +324,8 @@ ALPS_PY_EXPORT_SIMPLEOBSERVABLE(RealTimeSeriesObservable,timeseries_observable_d
 #define ALPS_MCANALYZE_EXPORT_SCALAR_AND_VECTOR(container_type, function_name_py, function_name_c, docstring)                           \
     ALPS_MCANALYZE_EXPORT_HELPER( < container_type < double > > , function_name_py, function_name_c , docstring)                        \
     ALPS_MCANALYZE_EXPORT_HELPER( < container_type < std::vector < double > > > , function_name_py, function_name_c , docstring)                                        
-//    ALPS_MCANALYZE_EXPORT_HELPER( < container_type < int > > , function_name_py, function_name_c , docstring)                         \
-    ALPS_MCANALYZE_EXPORT_HELPER( < container_type < std::vector < int > > > , function_name_py, function_name_c , docstring)                                        
+/*    ALPS_MCANALYZE_EXPORT_HELPER( < container_type < int > > , function_name_py, function_name_c , docstring)                         \
+    ALPS_MCANALYZE_EXPORT_HELPER( < container_type < std::vector < int > > > , function_name_py, function_name_c , docstring)*/
 
 #define ALPS_MCANALYZE_EXPORT_SCALAR_ONLY(container_type, function_name_py, function_name_c, docstring)                                 \
     ALPS_MCANALYZE_EXPORT_HELPER( < container_type < double > > , function_name_py, function_name_c , docstring)  
@@ -342,8 +336,8 @@ ALPS_PY_EXPORT_SIMPLEOBSERVABLE(RealTimeSeriesObservable,timeseries_observable_d
 #define ALPS_MCANALYZE_EXPORT_VALUETYPE_FUNCTION(function_name_py, function_name_c, docstring)                                          \
     ALPS_MCANALYZE_EXPORT_HELPER( < double > , function_name_py, function_name_c , docstring)                                           \
     ALPS_MCANALYZE_EXPORT_HELPER( < std::vector < double > > , function_name_py, function_name_c , docstring)
-//    ALPS_MCANALYZE_EXPORT_HELPER( < int > , function_name_py, function_name_c , docstring)                                            \
-    ALPS_MCANALYZE_EXPORT_HELPER( < std::vector < int > > , function_name_py, function_name_c , docstring)   
+/*    ALPS_MCANALYZE_EXPORT_HELPER( < int > , function_name_py, function_name_c , docstring)                                            \
+    ALPS_MCANALYZE_EXPORT_HELPER( < std::vector < int > > , function_name_py, function_name_c , docstring)*/
 
 
 #define ALPS_MCANALYZE_EXPORT_TIMESERIES_FUNCTION_SCALAR_AND_VECTOR(function_name_py, function_name_c, docstring)                       \
