@@ -83,14 +83,14 @@ class LatticeLibrary:
                                 for n3 in n2.childNodes:
                                     if n3.localName == 'LATTICE':
                                         ref = n3.getAttribute("ref")
-                                        if ref and latticeparams.has_key(ref):
+                                        if ref and ref in latticeparams:
                                             for k in latticeparams[ref].keys():
                                                 p[k] = latticeparams[ref][k]
                                     elif n3.localName == 'PARAMETER':
                                         p[n3.getAttribute("name")] = n3.getAttribute("default")
                                     elif n3.localName == 'EXTENT':
                                         size = n3.getAttribute("size")
-                                        if not p.has_key(size) and not size.isdigit():
+                                        if size not in p and not size.isdigit():
                                             p[size] = ""
                         self.graphs.append(name)
                         self.params[name] = p
@@ -254,7 +254,7 @@ class LatticeParameterWindow(wx.Frame):
         self.sizer.Add(wx.StaticLine(self), 0, wx.EXPAND|wx.TOP|wx.BOTTOM, 5)
 
         self.sizer.Add(wx.StaticText(self, -1, "Parameters:"), 0, wx.EXPAND|wx.ALL, 5)
-        self.fgs = wx.FlexGridSizer(3, 2, 5, 5)
+        self.fgs = wx.FlexGridSizer(0, 2, 5, 5)
         self.sizer.Add(self.fgs, 1, wx.EXPAND|wx.ALL, 15)
 
         btn_cancel = wx.Button(self, -1, "Cancel")
@@ -365,7 +365,7 @@ class LatticeParameterWindow(wx.Frame):
 
     def OnParameterInput(self, evt):
         key = evt.GetEventObject().GetName()
-        if self.parameters.has_key(key):
+        if key in self.parameters:
             self.parameters[key] = evt.GetEventObject().GetValue()
 
     def OnPreview(self, evt):
@@ -461,14 +461,14 @@ class PreviewLatticeWindow(wx.Frame):
         self.VertexColors = [
             [0.8,0.3,0.3], #dark red
             [0.4,0.6,0.5], #dark green 2
-            [0.7,0.5,0.2]  #orange 2
+            [0.8,0.6,0.3]  #orange 2
             ]
         for i in range(3, self.lattice.maxVertexType+1):
             self.VertexColors.append([random.random(),random.random(),random.random()])
         self.EdgeColors = [
             [0.4,0.6,0.5], #dark green 2
             [0.8,0.3,0.5], #dark red
-            [1.0,0.4,0.2]  #orange 2
+            [1.0,0.6,0.3]  #orange 2
             ]
         for i in range(3, self.lattice.maxEdgeType+1):
             self.EdgeColors.append([random.random(),random.random(),random.random()])
