@@ -26,11 +26,11 @@
 # 
 # ****************************************************************************
 
-import core.modules.module_registry
-import core.modules.basic_modules as basic
-from core.modules.vistrails_module import Module, ModuleError, NotCacheable
-from core.modules.python_source_configure import PythonSourceConfigurationWidget
-from core import debug
+import vistrails.core.modules.module_registry
+import vistrails.core.modules.basic_modules as basic
+from vistrails.core.modules.vistrails_module import Module, ModuleError, NotCacheable
+from vistrails.gui.modules.python_source_configure import PythonSourceConfigurationWidget
+from vistrails.core import debug
 
 import urllib, copy
 import traceback
@@ -195,13 +195,15 @@ class LoadAlpsMeasurements(Module):
 
 class LoadDMFTIterations(Module):
     """Load the data from successive DMFT-Iterations. Description of input ports:
-      @ResultFiles: The hdf5-files.
-      @Measurements: List of observables to load
+      @ResultFiles: The list of hdf5-files.
+      @Observable: Observable to load
+      @Measurements: List of measurements of the observable to load
       @PropertyPath: Hdf5-path to the parameters stored. Default: /parameters
       @ResultPath: Hdf5-path to the observables stored. Default: /simulation/iteration"""
 
     my_input_ports = [
         PortDescriptor('ResultFiles',ResultFiles),
+        PortDescriptor('Observable',basic.String),
         PortDescriptor('Measurements',basic.List),
         PortDescriptor('PropertyPath',basic.String),
         PortDescriptor('ResultPath',basic.String)
@@ -217,14 +219,14 @@ class LoadDMFTIterations(Module):
             loader = Hdf5Loader()
             if self.hasInputFromPort('ResultFiles'):
                 files = [f.props["filename"] for f in self.getInputFromPort('ResultFiles')]
-            datasets = []
+            if self.hasInputFromPort('Observable'):
+                obs = self.getInputFromPort('Observable')
             if self.hasInputFromPort('Measurements'):
-                datasets = loader.ReadMeasurementFromFile(files,measurements=self.getInputFromPort('Measurements'),proppath=propPath,respath=resPath)
+                datasets = loader.ReadDMFTIterations(files,observable=obs,measurements=self.getInputFromPort('Measurements'),proppath=propPath,respath=resPath)
             else:
-                datasets = loader.ReadMeasurementFromFile(files,measurements=None,proppath=propPath,respath=resPath)
+                datasets = loader.ReadDMFTIterations(files,observable=obs,proppath=propPath,respath=resPath)
             self.setResult('data',datasets)
 
-
 class LoadTimeEvolution(Module):
     """Load the data from successive TEBD-Iterations. Description of input ports:
       @ResultFiles: The hdf5-files.
@@ -259,7 +261,7 @@ class LoadTimeEvolution(Module):
                 for f in files:
                     try:
                         #open the file and open the results root group
-                        h5file = h5.iArchive(f)
+                        h5file = h5.archive(f, 'r')
                         #enumerate the subgroups
                         L=h5file.list_children(resroot)
                         #Create an iterator of length the number of subgroups
@@ -282,7 +284,7 @@ class LoadTimeEvolution(Module):
                 for f in files:
                     try:
                         #open the file and open the results root group
-                        h5file = h5.iArchive(f)
+                        h5file = h5.archive(f, 'r')
                         #enumerate the subgroups
                         L=h5file.list_children(resroot)
                         #Create an iterator of length the number of subgroups
@@ -364,6 +366,7 @@ class LoadAlpsSpectra(Module):
 class LoadAlpsEigenstateMeasurements(Module):
     """Load the observables of an ED or DMRG-simulation from hdf5 files. Description of input ports:
       @ResultFiles: The hdf5-files.
+      @Measurements: List of observables to load
       @PropertyPath: Hdf5-path to the parameters stored. Default: /parameters
       @SpectrumPath: Hdf5-path to the spectrum stored. Default: /spectrum"""
 
@@ -397,6 +400,38 @@ class LoadAlpsEigenstateMeasurements(Module):
             
         self.setResult('data',datasets)
 
+class LoadAlpsIterationMeasurements(Module):
+    """Load the data from successive MPS-Iterations. Description of input ports:
+      @ResultFiles: The hdf5-files.
+      @Measurements: List of observables to load
+      @PropertyPath: Hdf5-path to the parameters stored. Default: /parameters
+      @SpectrumPath: Hdf5-path to the spectrum stored. Default: /spectrum"""
+
+    my_input_ports = [
+        PortDescriptor('ResultFiles',ResultFiles),
+        PortDescriptor('PropertyPath',basic.String),
+        PortDescriptor('SpectrumPath',basic.String),
+        PortDescriptor('Measurements',basic.List)
+    ]
+    
+    my_output_ports = [
+        PortDescriptor('data',DataSets)
+    ]    
+    
+    def compute(self):
+        propPath= self.getInputFromPort('PropertyPath') if self.hasInputFromPort('PropertyPath') else "/parameters"
+        resPath= self.getInputFromPort('SpectrumPath') if self.hasInputFromPort('SpectrumPath') else "/spectrum"
+        loader = Hdf5Loader()
+        if self.hasInputFromPort('ResultFiles'):
+            files = [f.props["filename"] for f in self.getInputFromPort('ResultFiles')]
+        what = None
+        if self.hasInputFromPort('Measurements'):
+            what = self.getInputFromPort('Measurements')
+        
+        datasets = loader.ReadDiagDataFromFile(files,proppath=propPath,respath=resPath,
+                                               measurements=what,loadIterations=True)
+        self.setResult('data',datasets)
+
 class GroupDataSets(Module):
     """
     Group a list of DataSet instances into a hierchical list according to some choice of properties.
