@@ -10,16 +10,20 @@
 #
 ##############################################################################
 
-from core.modules.vistrails_module import Module, ModuleError, NotCacheable
-from core.configuration import ConfigurationObject
-import core.bundles
-import core.modules.basic_modules
-import core.modules.module_registry
-from packages.HTTP.init import HTTPFile
+from vistrails.core.modules.vistrails_module import Module, ModuleError, NotCacheable
+from vistrails.core.configuration import ConfigurationObject
+import vistrails.core.modules.basic_modules
+import vistrails.core.modules.module_registry
+try:
+  from vistrails.packages.HTTP.init import HTTPFile
+except:
+  from vistrails.packages.URL.init import DownloadFile
+  HTTPFile = DownloadFile
 import os
 import os.path
 import tempfile
 import copy
+import fnmatch
 import glob
 import zipfile
 import datetime
@@ -36,7 +40,7 @@ import pyalps
 import pyalps.pytools # the C++ conversion functions
 
 
-basic = core.modules.basic_modules
+basic = vistrails.core.modules.basic_modules
 
 ##############################################################################
 
@@ -132,6 +136,9 @@ class WriteInputFiles(Module):
          else:
            base_name = os.path.basename(o.name)
 
+         print(base_name);
+
+
          ofile = basic.File()
          ofile.name = os.path.join(dir.name,base_name + '.in.xml')
 
@@ -220,10 +227,17 @@ class Parameter2XML(alpscore.SystemCommandLogged):
                      ('output_dir', [basic.Directory]),
                      ('log_file',[basic.File])]
 
+# http://stackoverflow.com/a/2186639/720077
+def recursive_glob(treeroot, pattern):
+  results = []
+  for base, dirs, files in os.walk(treeroot):
+    goodfiles = fnmatch.filter(files, pattern)
+    results.extend(os.path.join(base, f) for f in goodfiles)
+  return results
 
 class Glob(Module):
     def expand(self,name):
-        l = recursive_glob(name)
+        l = recursive_glob('.', name)
         self.setResult('value',l)
     def compute(self):
       self.expand(self.getInputFromPort('input_file').name)
@@ -244,9 +258,9 @@ class GetCloneFiles(Module):
          if (self.hasInputFromPort('tasks')):
            tasks = str(self.getInputFromPort('tasks'))
          if (self.hasInputFromPort('runs')):
-           tasks = str(self.getInputFromPort('runs'))
+           runs = str(self.getInputFromPort('runs'))
          if (self.hasInputFromPort('prefix')):
-           tasks = str(self.getInputFromPort('prefix'))+'*'
+           prefix = str(self.getInputFromPort('prefix'))+'*'
          files = glob.glob(os.path.join(dirname,prefix+ '.task' + tasks + '.out.run' +runs))
 # remove HDF5 files from the list
          res = []
@@ -286,17 +300,48 @@ class GetResultFiles(Module):
                 tasks = self.getInputFromPort('tasks')
             if self.hasInputFromPort('prefix'):
                 prefix = self.getInputFromPort('prefix')
-            result = pyalps.recursiveGlob(dirname, prefix+ '.task' + tasks + '.out.xml')
+            if self.hasInputFromPort('format'):
+                fm = self.getInputFromPort('format')
+                if fm == 'hdf5':
+                    result = pyalps.recursiveGlob(dirname, prefix+ '.task' + tasks + '.out.h5')
+                else:
+                    result = pyalps.recursiveGlob(dirname, prefix+ '.task' + tasks + '.out.xml')
+            else:
+                result = pyalps.recursiveGlob(dirname, prefix+ '.task' + tasks + '.out.xml')
             self.setResult('value', result)
             self.setResult('resultfiles', [ResultFile(x) for x in result])
 
     _input_ports = [('dir',[basic.Directory]), 
         ('prefix',[basic.String]), 
         ('tasks',[basic.String]),
-        ('pattern',[basic.String])]
+        ('pattern',[basic.String]),
+        ('format',[basic.String])]
     _output_ports = [('value',[basic.List]),
         ('resultfiles',[ResultFiles])]
 
+class GetCheckpointFiles(Module):
+     """ 
+     This module gets all ALPS checkpoint files of MPS simulations in a given directory.
+     The tasks, and prefix inputs take regular expressions limiting the task numbers and prefix of the simulation. They default to '*', meaning all.
+     
+     """
+     def compute(self):
+         tasks = '*'
+         prefix = '*'
+         d = self.getInputFromPort('dir')
+         dirname = d.name
+         if (self.hasInputFromPort('tasks')):
+           tasks = str(self.getInputFromPort('tasks'))
+         if (self.hasInputFromPort('prefix')):
+           prefix = str(self.getInputFromPort('prefix'))+'*'
+         files = glob.glob(os.path.join(dirname,prefix+ '.task' + tasks + '.out.chkp'))
+         self.setResult('value',files)
+     _input_ports = [('dir',[basic.Directory]), 
+                     ('prefix',[basic.String]), 
+                     ('tasks',[basic.String])]
+     _output_ports = [('value',[basic.List])]
+
+
 class Convert2XML(Module):
     """
     This module takes a list of ALPS result or clone files and converts each of them to XML. It returns a list of the converted XML files. 
@@ -320,16 +365,9 @@ class ConvertXML2HTML(alpscore.SystemCommand):
         output_file = self.interpreter.filePool.create_file(suffix='.html')
         if platform.system() == 'Windows':
           cmdlist = ['msxsl.exe',input_file] + self.style + ['-o', output_file.name]
-        if platform.system() != 'Windows':
+        else:
           cmdlist = [alpscore._get_path('xslttransform')] + self.style + [input_file, '>' , output_file.name]
         self.execute(cmdlist)
-        if platform.system() == 'Windows': # need to convert to UTF-8
-          fin = codecs.open(output_file.name,"r","utf-16")
-          u = fin.read()
-          fin.close()
-          fout = file(output_file.name,"w")
-          fout.write(u.encode("utf-8"))
-          fout.close()
         return output_file
 
     def compute(self):
@@ -474,7 +512,7 @@ def initialize(): pass
 
 def selfRegister():
 
-  reg = core.modules.module_registry.get_module_registry()
+  reg = vistrails.core.modules.module_registry.get_module_registry()
   
   reg.add_module(WriteParameterFile,namespace="Tools",abstract=True)
   reg.add_module(WriteTEBDInputFiles,namespace="Tools")
@@ -484,6 +522,7 @@ def selfRegister():
   reg.add_module(Glob,namespace="Tools",abstract=True)
   reg.add_module(GetCloneFiles,namespace="Tools")
   reg.add_module(GetResultFiles,namespace="Tools")
+  reg.add_module(GetCheckpointFiles,namespace="Tools")
   
   reg.add_module(Convert2XML,namespace="Tools")
   reg.add_module(Convert2Text,namespace="Tools",abstract=True)
